@@ -38,16 +38,6 @@ impl From<serde_json::Error> for FlashResponse<Redirect> {
     }
 }
 
-// impl From<printnanny_services::printnanny_api::ServiceError> for FlashResponse<Redirect> {
-//     fn from(error: printnanny_services::printnanny_api::ServiceError) -> Self {
-//         let msg = format!("{:?}", error);
-//         let mut context = HashMap::new();
-//         context.insert("errors", &msg);
-//         error!("{}", &msg);
-//         Self(Flash::error(Redirect::to("/"), &msg))
-//     }
-// }
-
 impl From<printnanny_services::printnanny_api::ServiceError> for FlashResponse<Template> {
     fn from(error: printnanny_services::printnanny_api::ServiceError) -> Self {
         let msg = format!("{:?}", error);
@@ -58,6 +48,16 @@ impl From<printnanny_services::printnanny_api::ServiceError> for FlashResponse<T
     }
 }
 
+impl From<rocket::figment::Error> for FlashResponse<Template> {
+    fn from(error: rocket::figment::Error) -> Self {
+        let msg = format!("{:?}", error);
+        let mut context = HashMap::new();
+        context.insert("errors", &msg);
+        error!("{}", &msg);
+        Self(Flash::error(Template::render("error", context), &msg))
+    }
+}
+
 impl From<error::Error> for FlashResponse<Template> {
     fn from(error: error::Error) -> Self {
         let msg = format!("{:?}", error);
